/**
 * JASMINe
 * Copyright (C) 2009-2010 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: DataManagementService.java 9190 2011-10-14 14:37:43Z durieuxp $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.datamanagement.service;

import java.util.List;

import javax.naming.NamingException;

import org.apache.felix.ipojo.annotations.Component;
import org.apache.felix.ipojo.annotations.Instantiate;
import org.apache.felix.ipojo.annotations.Provides;
import org.apache.felix.ipojo.annotations.ServiceProperty;
import org.ow2.jasmine.event.messages.JasmineEventPurgeTask;
import org.ow2.jasmine.monitoring.eos.common.jndilocator.ServiceLocator;
import org.ow2.jasmine.monitoring.eventswitch.beans.JasmineEventPurgeTaskSLBRemote;
import org.ow2.kerneos.core.service.KerneosSimpleService;

import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * @author Francois Fornaciari
 */
@Component
@Instantiate
@Provides
public class DataManagementService implements KerneosSimpleService {

    protected Log logger = LogFactory.getLog(this.getClass());

    private static final long serialVersionUID = -8056979296509798113L;

    private JasmineEventPurgeTaskSLBRemote jasminePurgeTaskRemote = null;

    @ServiceProperty(name = KerneosSimpleService.ID, value = "datamanagementService")
    private String id;

    public DataManagementService() throws NamingException {
        this.jasminePurgeTaskRemote = (JasmineEventPurgeTaskSLBRemote) ServiceLocator.getInstance().getRemoteObject("db-ejb/purgetask");
    }

    public JasmineEventPurgeTask configurePurgeTask(final JasmineEventPurgeTask purgeTask) {
        return this.jasminePurgeTaskRemote.configurePurgeTask(purgeTask);
    }

    public List<JasmineEventPurgeTask> listPurgeTasks() {
        return jasminePurgeTaskRemote.listPurgeTasks();
    }

    public long removePurgeTask(final long purgeTaskId) throws Exception {
        return jasminePurgeTaskRemote.removePurgeTask(purgeTaskId);
    }

    public void startPurgeTask(final long purgeTaskId) throws Exception {
        jasminePurgeTaskRemote.startPurgeTask(purgeTaskId);
    }

    public void pausePurgeTask(final long purgeTaskId) throws Exception {
        jasminePurgeTaskRemote.pausePurgeTask(purgeTaskId);
    }
}
